@@ -1,6 +1,9 @@
 import asyncio
 import sys
 
+# rmtree msg on win32
+import warnings
+
 # import os
 import argparse
 
@@ -139,8 +142,13 @@ def cache_check(app_folder, devmode=False):
         cache_dir.mkdir(exist_ok=True)
 
     if clear_cache:
-        if shutil.rmtree.avoids_symlink_attacks:
+        win32 = sys.platform == "win32"
+        if shutil.rmtree.avoids_symlink_attacks or win32:
             if cache_dir.is_dir():
+                if win32:
+                    warnings.warn(
+                        "clear cache : rmtree is not safe on that system (win32)"
+                    )
                 shutil.rmtree(cache_dir.as_posix())
         else:
             print(
